==> v2.2.0.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/service/VppRTeamMemberRoleService.java <==
package cn.kdan.pdf.tech.core.service;

import cn.kdan.pdf.tech.core.model.VppRTeamMemberRole;
import cn.kdan.pdf.tech.core.model.VppRTeamMemberRoleExample;
import cn.kdan.pdf.tech.core.pojo.dto.AddTeamMemberDTO;
import cn.kdan.pdf.tech.core.pojo.vo.VppRTeamMemberRoleVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamAdminVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamMemberVO;
import com.github.pagehelper.PageInfo;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;
import pojo.ResultMap;

import java.util.List;

/**
 * @author tangxiangan
 */
public interface VppRTeamMemberRoleService {

    /**
     * 创建用户和团队的联系
     *
     * @param vppRTeamMemberRole vppRTeamMember
     */
    void create(VppRTeamMemberRole vppRTeamMemberRole);

    /**
     * 查出用户管理的所有团队
     *
     * @param memberId 用户id
     * @return List
     */
    List<VppRTeamMemberRoleVO> listByMemberIdAdmin(String memberId);

    List<String> getTeamIdByAdminName(String admin);

    /**
     * 获取团队所有关联关系
     * @param teamId 用户id
     * @return List
     */
    List<VppRTeamMemberRole> getAllByTeamId(String teamId);

    /**
     * 查出用户与某个团队的关联记录
     *
     * @param memberId 用户id
     * @param teamId   团队id
     * @return List
     */
    List<VppRTeamMemberRole> listByMemberIdAndTeamId(String memberId, String teamId);

    List<VppRTeamMemberRole> listByMemberId(String memberId);

    Integer countMenberNumByTeamIdList(List<String> teamIdList);

    void addTeamMember(AddTeamMemberDTO dto);

    /**
     * 导入批量添加团队成员
     * @param file 文件
     * @return
     */
    String addTeamMemberBatch(MultipartFile file);

    String confirmTeamMember(String memberEmail, String memberName, String teamId, String action, String code);

    /**
     * 编辑团队成员
     *
     * @param memberId 用户id
     * @param teamId   团队id
     * @param name     用户名字
     */
    void editTeamMember(String memberId, String teamId, String name);

    /**
     * 删除用户
     *
     * @param memberId 用户id
     */
    void deleteMember(String memberId);

    /**
     * 删除管理员管理的所有团队的关联关系，并且解绑管理员关联的设备，将管理员作为一个普通成员的省份方法哦默认团队
     *
     * @param memberId 用户id
     */
    void deleteAdmin(String memberId);

    void logOutUserNoAdmin(String memberId);

    /**
     * 清空团队管理员
     * @param teamId 团队id
     */
    void cleanTeamAdmin(String teamId);

    /**
     * 清空团队所有关联关系
     * @param teamId 团队id
     */
    void cleanTeamMember(String teamId);

    void changeTeamMember(String teamId, String toTeamId);

    int deleteByExample(VppRTeamMemberRoleExample example);

    /**
     * 用户退出团队
     *
     * @param memberId 用户id
     * @param teamIds  团队id结合
     */
    void quitTeam(String memberId, List<String> teamIds);

    /**
     * 修改用户与团队关联关系
     *
     * @param vppRTeamMemberRole vppRTeamMemberRole
     */
    void update(VppRTeamMemberRole vppRTeamMemberRole);

    /**
     * 分页查询团队里的管理员
     *
     * @param page        页数
     * @param pageSize    一页最大条数
     * @param teamId      团队id
     * @param role        权限
     * @param queryString 名字或者邮箱
     * @return PageInfo
     */
    PageInfo<VppTeamAdminVO> pageForAdmin(Integer page, Integer pageSize, String teamId, String role, String queryString);

    /**
     * 分页查询团队里的成员
     *
     * @param page 页数
     * @param pageSize 条数
     * @param teamId 团队id
     * @param status 团队状态
     * @param productCode 产品code
     * @param queryString queryString
     * @return PageInfo
     */
    PageInfo<VppTeamMemberVO> pageForMember(Integer page, Integer pageSize, String teamId, String status, String productCode, String queryString);

    /**
     *  列表用于导出
     * @param teamId
     * @param status
     * @param productCode
     * @param queryString
     * @return
     */
    List<VppTeamMemberVO> listForMember(String teamId, String status, String productCode, String queryString);

    /**
     * 获取成员所在团队id
     * @return
     */
    String getMemberTeam(String memberId);

    /**
     * 查询团队下的所有用户(用于序列码单个授权时选择用户)
     *
     * @param teamId 团队id
     * @return List
     */
    List<VppTeamAdminVO> listByTeamId(String teamId);

    /**
     * 获取团队下除了超管外其他所有角色的用户关系
     *
     * @param teamId teamId
     * @return List
     */
    List<VppRTeamMemberRole> listByTeamIdWithoutSuperAdmin(String teamId);
}

==> v3.0.1.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/service/VppRTeamMemberRoleService.java <==
package cn.kdan.pdf.tech.core.service;

import cn.kdan.pdf.tech.core.model.VppRTeamMemberRole;
import cn.kdan.pdf.tech.core.model.VppRTeamMemberRoleExample;
import cn.kdan.pdf.tech.core.pojo.dto.AddTeamMemberDTO;
import cn.kdan.pdf.tech.core.pojo.vo.VppRTeamMemberRoleVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamAdminVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamMemberVO;
import com.github.pagehelper.PageInfo;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * @author tangxiangan
 */
public interface VppRTeamMemberRoleService {

    /**
     * 创建用户和团队的联系
     *
     * @param vppRTeamMemberRole vppRTeamMember
     */
    void create(VppRTeamMemberRole vppRTeamMemberRole);

    /**
     * 查出用户管理的所有团队
     *
     * @param memberId 用户id
     * @return List
     */
    List<VppRTeamMemberRoleVO> listByMemberIdAdmin(String memberId);

    List<String> getTeamIdByAdminName(String admin);

    /**
     * 获取团队所有关联关系
     * @param teamId 用户id
     * @return List
     */
    List<VppRTeamMemberRole> getAllByTeamId(String teamId);

    /**
     * 查出用户与某个团队的关联记录
     *
     * @param memberId 用户id
     * @param teamId   团队id
     * @return List
     */
    List<VppRTeamMemberRole> listByMemberIdAndTeamId(String memberId, String teamId);

    List<VppRTeamMemberRole> listByMemberId(String memberId);

    Integer countMenberNumByTeamIdList(List<String> teamIdList);

    void addTeamMember(AddTeamMemberDTO dto);

    /**
     * 导入批量添加团队成员
     * @param file 文件
     * @return
     */
    String addTeamMemberBatch(MultipartFile file);

    String confirmTeamMember(String memberEmail, String memberName, String teamId, String action, String code);

    /**
     * 编辑团队成员
     *
     * @param memberId 用户id
     * @param teamId   团队id
     * @param name     用户名字
     */
    void editTeamMember(String memberId, String teamId, String name);

    /**
     * 删除用户
     *
     * @param memberId 用户id
     */
    void deleteMember(String memberId);

    /**
     * 删除管理员管理的所有团队的关联关系，并且解绑管理员关联的设备，将管理员作为一个普通成员的省份方法哦默认团队
     *
     * @param memberId 用户id
     */
    void deleteAdmin(String memberId);

    void logOutUserNoAdmin(String memberId);

    /**
     * 清空团队管理员
     * @param teamId 团队id
     */
    void cleanTeamAdmin(String teamId);

    /**
     * 清空团队所有关联关系
     * @param teamId 团队id
     */
    void cleanTeamMember(String teamId);

    void changeTeamMember(String teamId, String toTeamId);

    int deleteByExample(VppRTeamMemberRoleExample example);

    /**
     * 用户退出团队
     *
     * @param memberId 用户id
     * @param teamIds  团队id结合
     */
    void quitTeam(String memberId, List<String> teamIds);

    /**
     * 修改用户与团队关联关系
     *
     * @param vppRTeamMemberRole vppRTeamMemberRole
     */
    void update(VppRTeamMemberRole vppRTeamMemberRole);

    /**
     * 分页查询团队里的管理员
     *
     * @param page        页数
     * @param pageSize    一页最大条数
     * @param teamId      团队id
     * @param role        权限
     * @param queryString 名字或者邮箱
     * @return PageInfo
     */
    PageInfo<VppTeamAdminVO> pageForAdmin(Integer page, Integer pageSize, String teamId, String role, String queryString);

    /**
     * 分页查询团队里的成员
     *
     * @param page        页数
     * @param pageSize    条数
     * @param teamId      团队id
     * @param status      团队状态
     * @param productCode 产品code
     * @param queryString queryString
     * @param domain
     * @return PageInfo
     */
    PageInfo<VppTeamMemberVO> pageForMember(Integer page, Integer pageSize, String teamId, String status, String productCode, String queryString, String isSso, String domain);

    /**
     * 列表用于导出
     *
     * @param teamId
     * @param status
     * @param productCode
     * @param queryString
     * @param domain
     * @return
     */
    List<VppTeamMemberVO> listForMember(String teamId, String status, String productCode, String queryString, String isSso, String domain);

    /**
     * 获取成员所在团队id
     * @return
     */
    String getMemberTeam(String memberId);

    /**
     * 查询团队下的所有用户(用于序列码单个授权时选择用户)
     *
     * @param teamId 团队id
     * @return List
     */
    List<VppTeamAdminVO> listByTeamId(String teamId);

    /**
     * 获取团队下除了超管外其他所有角色的用户关系
     *
     * @param teamId teamId
     * @return List
     */
    List<VppRTeamMemberRole> listByTeamIdWithoutSuperAdmin(String teamId);

    /**
     * 删除sso用户
     *
     * @param memberIds 用户id
     */
    void removeSSOMembers(List<String> memberIds);

    /**
     * 吊销sso用户（暂时冻结登录和使用）
     * @param memberId 用户id
     */
    void revokeSSOMember(String memberId);

    /**
     * 还原用户
     *
     * @param memberIds 用户id
     */
    void reductionSSOMember(List<String> memberIds);
    /**
     * 取消吊销用户
     * @param memberId 用户id
     */
    void accessSSOMember(String memberId);
}
